@@ -841,7 +841,7 @@ CmdFindLabel(
 	return;
     };
 
-    labname = cmd->tx_argv[1 + (doglob) ? 1 : 0];
+    labname = cmd->tx_argv[1 + ((doglob) ? 1 : 0)];
     labUse = EditCellUse;
     if (labUse == NULL) labUse = (CellUse *)w->w_surfaceID;
 
@@ -1783,7 +1783,7 @@ CmdGoto(
     MagWindow *w,
     TxCommand *cmd)
 {
-    char	*s, *nodename = cmd->tx_argv[1];
+    char	*nodename = cmd->tx_argv[1];
     Rect	rect;
     CellUse	*use;
     int		locargc;
@@ -1824,9 +1824,9 @@ CmdGoto(
     /* are multiple layers drawn at the indicated point.		*/
 
 #ifdef MAGIC_WRAPPER
-    Tcl_SetResult(magicinterp, DBTypeLongName(ttype), NULL);
+    Tcl_SetResult(magicinterp, (char*)DBTypeLongName(ttype), NULL); /* Tcl treats as const */
 #else
-    TxPrintf("node %s is type %s\n", s, DBTypeLongName(ttype));
+    TxPrintf("node %s is type %s\n", nodename, DBTypeLongName(ttype));
 #endif
 }
 
