@@ -14,7 +14,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/ext2spice/ext2hier.c,v 1.5 2010/12/16 18:59:03 tim Exp $";
+static const char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/ext2spice/ext2hier.c,v 1.5 2010/12/16 18:59:03 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -71,13 +71,13 @@ typedef struct _defflagsdata {
  */
 
 void
-ESGenerateHierarchy(inName, flags)
-    char *inName;
-    int flags;
+ESGenerateHierarchy(
+    char *inName,
+    int flags)
 {
-    int esHierVisit(), esMakePorts();	/* Forward declaration */
+    int esHierVisit(HierContext *hc, ClientData cdata); /* (DefFlagsData *) */
+    int esMakePorts(HierContext *hc, ClientData cdata);	/* Forward declaration (UNUSED) */
     Use u;
-    Def *def;
     HierContext hc;
     DefFlagsData dfd;
 
@@ -112,13 +112,12 @@ ESGenerateHierarchy(inName, flags)
  */
 
 EFNode *
-GetHierNode(hc, name)
-    HierContext *hc;
-    HierName *name;
+GetHierNode(
+    HierContext *hc,
+    HierName *name)
 {
     HashEntry *he;
     EFNodeName *nn;
-    Def *def = hc->hc_use->use_def;
 
     he = EFHNConcatLook(hc->hc_hierName, name, "node");
     if (he == NULL) return NULL;
@@ -140,18 +139,17 @@ GetHierNode(hc, name)
  */
 
 void
-spcHierWriteParams(hc, dev, scale, l, w, sdM)
-    HierContext *hc;
-    Dev *dev;           /* Dev being output */
-    float scale;        /* Scale transform for output */
-    int l;              /* Device length, in internal units */
-    int w;              /* Device width, in internal units */
-    float sdM;          /* Device multiplier */
+spcHierWriteParams(
+    HierContext *hc,
+    Dev *dev,           /* Dev being output */
+    float scale,        /* Scale transform for output */
+    int l,              /* Device length, in internal units */
+    int w,              /* Device width, in internal units */
+    float sdM)          /* Device multiplier */
 {
-    bool hierD;
     DevParam *plist, *dparam;
     int parmval;
-    EFNode *dnode, *subnodeFlat = NULL;
+    EFNode *dnode;
 
     /* Write all requested parameters to the subcircuit call.	*/
 
@@ -345,7 +343,7 @@ spcHierWriteParams(hc, dev, scale, l, w, sdM)
 		break;
 	    case 's':
 		fprintf(esSpiceF, " %s=", plist->parm_name);
-		subnodeFlat = spcdevSubstrate(hc->hc_hierName,
+		/*EFNode *subnodeFlat =*/ spcdevSubstrate(hc->hc_hierName,
 			dev->dev_subsnode->efnode_name->efnn_hier,
 			dev->dev_type, esSpiceF);
 		break;
@@ -373,11 +371,11 @@ spcHierWriteParams(hc, dev, scale, l, w, sdM)
 		break;
 	    case 'r':
 		fprintf(esSpiceF, " %s=", plist->parm_name);
-		fprintf(esSpiceF, "%f", (double)(dev->dev_res));
+		esSIvalue(esSpiceF, (double)(dev->dev_res));
 		break;
 	    case 'c':
 		fprintf(esSpiceF, " %s=", plist->parm_name);
-		fprintf(esSpiceF, "%ff", (double)(dev->dev_cap));
+		esSIvalue(esSpiceF, (double)(dev->dev_cap));
 		break;
 	}
 	plist = plist->parm_next;
@@ -410,18 +408,18 @@ spcHierWriteParams(hc, dev, scale, l, w, sdM)
  */
 
 void
-esOutputHierResistor(hc, dev, scale, term1, term2, has_model, l, w, dscale)
-    HierContext *hc;
-    Dev *dev;			/* Dev being output */
-    float scale;		/* Scale transform for output */
-    DevTerm *term1, *term2;	/* Terminals of the device */
-    bool has_model;		/* Is this a modeled resistor? */
-    int l, w;			/* Device length and width */
-    int dscale;			/* Device scaling (for split resistors) */
+esOutputHierResistor(
+    HierContext *hc,
+    Dev *dev,			/* Dev being output */
+    float scale,		/* Scale transform for output */
+    DevTerm *term1,
+    DevTerm *term2,		/* Terminals of the device */
+    bool has_model,		/* Is this a modeled resistor? */
+    int l,
+    int w,			/* Device length and width */
+    int dscale)			/* Device scaling (for split resistors) */
 {
-    Rect r;
-    float sdM ;
-    char name[12], devchar;
+    float sdM;
 
     /* Resistor is "Rnnn term1 term2 value" 		 */
     /* extraction sets two terminals, which are assigned */
@@ -482,10 +480,10 @@ esOutputHierResistor(hc, dev, scale, term1, term2, has_model, l, w, dscale)
  */
 
 int
-subcktHierVisit(use, hierName, is_top)
-    Use *use;
-    HierName *hierName;
-    bool is_top;                /* TRUE if this is the top-level cell */
+subcktHierVisit(
+    Use *use,
+    HierName *hierName,
+    bool is_top)                /* TRUE if this is the top-level cell */
 {
     Def *def = use->use_def;
     EFNode *snode;
@@ -569,18 +567,20 @@ subcktHierVisit(use, hierName, is_top)
  * ----------------------------------------------------------------------------
  */
 
+/* ARGSUSED */
+/* @typedef cb_extflat_hiervisitdevs_t (UNUSED) */
 int
-spcdevHierVisit(hc, dev, scale)
-    HierContext *hc;
-    Dev *dev;		/* Dev being output */
-    float scale;	/* Scale transform for output */
+spcdevHierVisit(
+    HierContext *hc,
+    Dev *dev,		/* Dev being output */
+    float scale,	/* Scale transform for output */
+    ClientData cdata)	/* unused */
 {
     DevParam *plist, *pptr;
     DevTerm *gate, *source, *drain;
     EFNode  *subnode, *snode, *dnode, *subnodeFlat = NULL;
-    int l, w, i, parmval;
-    Rect r;
-    bool subAP = FALSE, hierS, hierD, extHierSDAttr();
+    int l, w, i;
+    bool subAP = FALSE;
     float sdM;
     char devchar;
     bool has_model = TRUE;
@@ -688,6 +688,9 @@ spcdevHierVisit(hc, dev, scale)
 	case DEV_CAPREV:
 	    devchar = 'C';
 	    break;
+	case DEV_VERILOGA:
+	    devchar = 'N';
+	    break;
 	case DEV_SUBCKT:
 	case DEV_RSUBCKT:
 	case DEV_CSUBCKT:
@@ -725,6 +728,7 @@ spcdevHierVisit(hc, dev, scale)
 		fprintf(esSpiceF, "%d", esVoltNum++);
 		break;
 	    case DEV_SUBCKT:
+	    case DEV_VERILOGA:
 	    case DEV_RSUBCKT:
 	    case DEV_CSUBCKT:
 	    case DEV_MSUBCKT:
@@ -778,6 +782,7 @@ spcdevHierVisit(hc, dev, scale)
 	    /* Drop through to below (no break statement) */
 
 	case DEV_SUBCKT:
+	case DEV_VERILOGA:
 	case DEV_CSUBCKT:
 
 	    /* Subcircuit is "Xnnn gate [source [drain [sub]]]"		*/
@@ -809,8 +814,8 @@ spcdevHierVisit(hc, dev, scale)
 		    spcdevOutNode(hc->hc_hierName, source->dterm_node->efnode_name->efnn_hier,
 				"subckt", esSpiceF);
 	    }
-	    /* The following only applies to DEV_SUBCKT*, which may define as	*/
-	    /* many terminal types as it wants.					*/
+	    /* The following only applies to DEV_SUBCKT and DEV_VERILOGA, which	*/
+	    /* may define as many terminal types as they want.			*/
 
 	    for (i = 4; i < dev->dev_nterm; i++)
 	    {
@@ -835,6 +840,8 @@ spcdevHierVisit(hc, dev, scale)
 			subnode->efnode_name->efnn_hier,
 			dev->dev_type, esSpiceF);
 	    }
+	    /* Support for CDL format */
+	    if (esFormat == CDL) fprintf(esSpiceF, " /");
 	    fprintf(esSpiceF, " %s", EFDevTypes[dev->dev_type]);
 
 	    /* Write all requested parameters to the subcircuit call.	*/
@@ -1075,8 +1082,10 @@ spcdevHierVisit(hc, dev, scale)
 	    /*
 	     * Check controlling attributes and output area and perimeter.
 	     */
-	    hierS = extHierSDAttr(source);
-	    hierD = extHierSDAttr(drain);
+#if 0 /* -Wunused-but-set-variable  extHierSDAttr() has no side-effects */
+	    bool hierS = extHierSDAttr(source);
+	    bool hierD = extHierSDAttr(drain);
+#endif
 	    if ( gate->dterm_attrs )
 		subAP = Match(ATTR_SUBSAP, gate->dterm_attrs ) ;
 
@@ -1147,16 +1156,20 @@ spcdevHierVisit(hc, dev, scale)
  * ----------------------------------------------------------------------------
  */
 
+/* ARGSUSED */
+/* @typedef cb_extflat_hiervisitdevs_t (UNUSED) */
 int
-spcdevHierMergeVisit(hc, dev, scale)
-    HierContext *hc;
-    Dev *dev;		/* Dev being output */
-    float scale;	/* Scale of transform (may be non-integer) */
+spcdevHierMergeVisit(
+    HierContext *hc,
+    Dev *dev,		/* Dev being output */
+    float scale,	/* Scale of transform (may be non-integer) */
+    ClientData cdata)	/* unused */
 {
     DevTerm *gate, *source, *drain;
     EFNode *subnode, *snode, *dnode, *gnode;
     int pmode, l, w;
-    devMerge *fp, *cfp;
+    devMerge *fp;
+    const devMerge *cfp;
     float m;
 
     /* If no terminals, or only a gate, can't do much of anything */
@@ -1268,12 +1281,15 @@ spcdevHierMergeVisit(hc, dev, scale)
  * ----------------------------------------------------------------------------
  */
 
+/* ARGSUSED */
+/* @typedef cb_extflat_hiervisitdevs_t (UNUSED) */
 int
-spccapHierVisit(hc, hierName1, hierName2, cap)
-    HierContext *hc;
-    HierName *hierName1;
-    HierName *hierName2;
-    double cap;
+spccapHierVisit(
+    HierContext *hc,
+    HierName *hierName1,
+    HierName *hierName2,
+    double cap,
+    ClientData cdata)	/* unused */
 {
     cap = cap / 1000;
     if (fabs(cap) <= EFCapThreshold)
@@ -1312,12 +1328,16 @@ spccapHierVisit(hc, hierName1, hierName2, cap)
  *
  * ----------------------------------------------------------------------------
  */
+
+/*ARGUSED*/
+/* @typedef cb_extflat_hiervisitresists_t (UNUSED) */
 int
-spcresistHierVisit(hc, hierName1, hierName2, res)
-    HierContext *hc;
-    HierName *hierName1;
-    HierName *hierName2;
-    float res;
+spcresistHierVisit(
+    HierContext *hc,
+    const HierName *hierName1,
+    const HierName *hierName2,
+    float res,
+    ClientData cdata)	// UNUSED
 {
     HashEntry *he;
     EFNodeName *nn;
@@ -1376,15 +1396,15 @@ spcresistHierVisit(hc, hierName1, hierName2, res)
  */
 
 int
-spcsubHierVisit(hc, node, res, cap, resstrptr)
-    HierContext *hc;
-    EFNode *node;
-    int res; 		// Unused
-    double cap;		// Unused
-    char **resstrptr;
+spcsubHierVisit(
+    HierContext *hc,
+    EFNode *node,
+    int res, 		// Unused
+    double cap,		// Unused
+    char **resstrptr)
 {
     HierName *hierName;
-    char *nsn;
+    const char *nsn;
 
     if (node->efnode_flags & EF_GLOB_SUBS_NODE)
     {
@@ -1414,13 +1434,12 @@ spcsubHierVisit(hc, node, res, cap, resstrptr)
  */
 
 int
-spcnodeHierVisit(hc, node, res, cap)
-    HierContext *hc;
-    EFNode *node;
-    int res;
-    double cap;
+spcnodeHierVisit(
+    HierContext *hc,
+    EFNode *node,
+    int res,
+    double cap)
 {
-    EFNodeName *nn;
     HierName *hierName;
     bool isConnected = FALSE;
     const char *fmt, *nsn;
@@ -1495,14 +1514,14 @@ spcnodeHierVisit(hc, node, res, cap)
  */
 static char esTempName[MAX_STR_SIZE];
 
-char *nodeSpiceHierName(hc, hname)
-    HierContext *hc;
-    HierName *hname;
+const char *
+nodeSpiceHierName(
+    HierContext *hc,
+    const HierName *hname)
 {
     EFNodeName *nn;
-    HashEntry *he, *he2;
+    HashEntry *he;
     EFNode *node;
-    Def *def = hc->hc_use->use_def;
 
     he = EFHNLook(hname, NULL, "ext2spice");
     if (he == NULL) return "error";
@@ -1553,22 +1572,21 @@ retName:
  */
 
 int
-devMergeHierVisit(hc, dev, scale)
-    HierContext *hc;
-    Dev *dev;			/* Dev to examine */
-    float scale;		/* Scale transform of output */
+devMergeHierVisit(
+    HierContext *hc,
+    Dev *dev,			/* Dev to examine */
+    float scale)		/* Scale transform of output */
 {
     DevTerm *gate, *source, *drain;
-    Dev     *cf;
-    DevTerm *cg, *cs, *cd;
     EFNode *subnode, *snode, *dnode, *gnode;
     int      pmode, l, w;
     bool     hS, hD, chS, chD;
-    devMerge *fp, *cfp;
+    devMerge *fp;
+    const devMerge *cfp;
     float m;
 
     if (esDistrJunct)
-	devDistJunctHierVisit(hc, dev, scale);
+	devDistJunctHierVisit(hc, dev, scale, PTR2CD(NULL));
 
     if (dev->dev_nterm < 2)
     {
@@ -1615,9 +1633,12 @@ devMergeHierVisit(hc, dev, scale)
     {
 	if ((pmode = parallelDevs(fp, cfp)) != NOT_PARALLEL)
 	{
-	    cf = cfp->dev;
-	    cg = &cfp->dev->dev_terms[0];
-	    cs = cd = &cfp->dev->dev_terms[1];
+#if 0 /* -Wunused-but-set-variable cf, cg */
+	    Dev *cf = cfp->dev;
+	    DevTerm *cg = &cfp->dev->dev_terms[0];
+#endif
+	    DevTerm *cs = &cfp->dev->dev_terms[1];
+	    DevTerm *cd = cs;
 	    if (cfp->dev->dev_nterm >= 3)
 	    {
 		if (pmode == PARALLEL)
@@ -1714,11 +1735,14 @@ mergeThem:
  * ----------------------------------------------------------------------------
  */
 
+/* ARGSUSED */
+/* @typedef cb_extflat_hiervisitdevs_t (UNUSED) */
 int
-devDistJunctHierVisit(hc, dev, scale)
-    HierContext *hc;
-    Dev *dev;			/* Dev to examine */
-    float scale;		/* Scale tranform of output */
+devDistJunctHierVisit(
+    HierContext *hc,
+    Dev *dev,			/* Dev to examine */
+    float scale,		/* Scale tranform of output */
+    ClientData cdata)		/* unused */
 {
     EFNode  *n;
     int i, l, w;
@@ -1767,9 +1791,9 @@ typedef struct _flagDefRecord {
  */
 
 int
-esMakePorts(hc, cdata)
-    HierContext *hc;
-    ClientData cdata;
+esMakePorts(
+    HierContext *hc,
+    ClientData cdata)
 {
     Connection *conn;
     Def *def = hc->hc_use->use_def, *portdef, *updef;
@@ -1840,7 +1864,6 @@ esMakePorts(hc, cdata)
 
 	    while (tptr != NULL)
 	    {
-		int idum[6];
 		bool is_array;
 
 		/* Ignore array information for the purpose of tracing	*/
@@ -2071,9 +2094,9 @@ esMakePorts(hc, cdata)
  */
 
 int
-esHierVisit(hc, cdata)
-    HierContext *hc;
-    ClientData cdata;
+esHierVisit(
+    HierContext *hc,
+    ClientData cdata)
 {
     HierContext *hcf;
     Def *def = hc->hc_use->use_def;
@@ -2179,23 +2202,23 @@ esHierVisit(hc, cdata)
 	/* Merge devices */
 	if (esMergeDevsA || esMergeDevsC)
 	{
-	    devMerge *p;
+	    const devMerge *p;
 
 	    EFHierVisitDevs(hcf, spcdevHierMergeVisit, (ClientData)NULL);
 	    TxPrintf("Devs merged: %d\n", esSpiceDevsMerged);
 	    esFMIndex = 0;
 	    for (p = devMergeList; p != NULL; p = p->next)
-		freeMagic(p);
+		freeMagic((char *)p);
 	    devMergeList = NULL;
 	}
 	else if (esDistrJunct)
-	    EFHierVisitDevs(hcf, devDistJunctHierVisit, (ClientData)NULL);
+	    EFHierVisitDevs(hcf, devDistJunctHierVisit, PTR2CD(NULL));
 
 	/* Output devices */
-	EFHierVisitDevs(hcf, spcdevHierVisit, (ClientData)NULL);
+	EFHierVisitDevs(hcf, spcdevHierVisit, PTR2CD(NULL));
 
 	/* Output lumped parasitic resistors */
-	EFHierVisitResists(hcf, spcresistHierVisit, (ClientData)NULL);
+	EFHierVisitResists(hcf, spcresistHierVisit, PTR2CD(NULL));
 
 	/* Output coupling capacitances */
 	EFHierVisitCaps(hcf, spccapHierVisit, (ClientData)NULL);
