@@ -49,7 +49,8 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
 /* This must match the definition for extDevTable in extract/ExtBasic.c */
 const char * const extDevTable[] = {"fet", "mosfet", "asymmetric", "bjt", "devres",
 		"devcap", "devcaprev", "vsource", "diode", "pdiode",
-		"ndiode", "subckt", "rsubckt", "msubckt", "csubckt", NULL};
+		"ndiode", "subckt", "rsubckt", "msubckt", "csubckt",
+		"veriloga", NULL};
 #endif
 
 /*
@@ -106,7 +107,7 @@ float locScale;		/* Multiply values in the file by this on read-in */
 bool EFSaveLocs;	/* If TRUE, save location of merged top-level nodes */
 
 /* Data local to this file */
-static bool efReadDef();
+static bool efReadDef(Def *def, bool dosubckt, bool resist, bool noscale, bool toplevel, bool isspice);
 
 /* atoCap - convert a string to a EFCapValue */
 #define	atoCap(s)	((EFCapValue)atof(s))
@@ -179,9 +180,13 @@ EFReadFile(name, dosubckt, resist, noscale, isspice)
  */
 
 bool
-efReadDef(def, dosubckt, resist, noscale, toplevel, isspice)
-   Def *def;
-   bool dosubckt, resist, noscale, toplevel, isspice;
+efReadDef(
+   Def *def,
+   bool dosubckt,
+   bool resist,
+   bool noscale,
+   bool toplevel,
+   bool isspice)
 {
     int argc, ac, n;
     CellDef *dbdef;
@@ -368,6 +373,7 @@ readfile:
 			   ac = 9;	/* Has device L and W */
 			break;
 		    case DEV_SUBCKT:
+		    case DEV_VERILOGA:
 		    case DEV_MSUBCKT:
 		    case DEV_RSUBCKT:
 		    case DEV_CSUBCKT:
