@@ -186,6 +186,7 @@ EFGetLengthAndWidth(dev, lptr, wptr)
 	case DEV_ASYMMETRIC:
 	case DEV_BJT:
 	case DEV_SUBCKT:
+	case DEV_VERILOGA:
 	case DEV_MSUBCKT:
 	case DEV_RSUBCKT:
 	case DEV_CSUBCKT:
@@ -246,14 +247,15 @@ EFGetLengthAndWidth(dev, lptr, wptr)
  * Visit all the devs in the circuit.
  * Must be called after EFFlatBuild().
  * For each dev in the circuit, call the user-supplied procedure
- * (*devProc)(), which should be of the following form:
+ * (*devProc)(), which should be of the following form
+ *   see also typedef cb_extflat_visitdevs_t:
  *
- *	(*devProc)(dev, hierName, scale, cdata)
- *	    Dev *dev;
- *	    HierName *hierName;
- *	    float scale;
- *	    Transform *trans;
- *	    ClientData cdata;
+ *	int (*devProc)(
+ *	    Dev *dev,
+ *	    HierContext *hc,
+ *	    float scale,
+ *	    Transform *trans,
+ *	    ClientData cdata)
  *	{
  *	}
  *
@@ -274,13 +276,13 @@ EFGetLengthAndWidth(dev, lptr, wptr)
  */
 
 int
-EFVisitDevs(devProc, cdata)
-    int (*devProc)();
-    ClientData cdata;
+EFVisitDevs(
+    const cb_extflat_visitdevs_t devProc,
+    ClientData cdata)
 {
     CallArg ca;
 
-    ca.ca_proc = devProc;
+    ca.ca_proc = (int (*)()) devProc;
     ca.ca_cdata = cdata;
     return efVisitDevs(&efFlatContext, (ClientData) &ca);
 }
@@ -326,7 +328,8 @@ efVisitDevs(hc, ca)
 	if (efDevKilled(dev, hc->hc_hierName))
 	    continue;
 
-	if ((*ca->ca_proc)(dev, hc, scale, &t, ca->ca_cdata))
+	const cb_extflat_visitdevs_t ca_visitdevs_proc = (cb_extflat_visitdevs_t) ca->ca_proc; /* FIXME temporary */
+	if ((*ca_visitdevs_proc)(dev, hc, scale, &t, ca->ca_cdata)) /* @invoke cb_extflat_visitdevs_t */
 	    return 1;
     }
     return 0;
@@ -454,12 +457,14 @@ skip:
  * Must be called after EFFlatBuild().
  * For each resistor in the circuit, call the user-supplied procedure
  * (*resProc)(), which should be of the following form, where hn1 and
- * hn2 are the HierNames of the two nodes connected by the resistor.
+ * hn2 are the HierNames of the two nodes connected by the resistor
+ *   see also typedef cb_extflat_visitresists_t:
  *
- *	(*resProc)(hn1, hn2, resistance, cdata)
- *	    HierName *hn1, *hn2;
- *	    int resistance;
- *	    ClientData cdata;
+ *	int (*resProc)(
+ *	    const HierName *hn1,
+ *	    const HierName *hn2,
+ *	    float resistance,
+ *	    ClientData cdata)
  *	{
  *	}
  *
@@ -480,15 +485,15 @@ skip:
  */
 
 int
-EFVisitResists(resProc, cdata)
-    int (*resProc)();
-    ClientData cdata;
+EFVisitResists(
+    const cb_extflat_visitresists_t resProc,
+    ClientData cdata)
 {
     CallArg ca;
 
-    ca.ca_proc = resProc;
+    ca.ca_proc = (int (*)()) resProc;
     ca.ca_cdata = cdata;
-    return efVisitResists(&efFlatContext, (ClientData) &ca);
+    return efVisitResists(&efFlatContext, &ca);
 }
 
 /*
@@ -502,7 +507,8 @@ EFVisitResists(resProc, cdata)
  *	Calls the client procedure (*ca->ca_proc)().
  */
 
-extern int efVisitSingleResist();
+extern int efVisitSingleResist(HierContext *hc, const char *name1, const char *name2,
+                               Connection *res, ClientData cdata); /* @typedef cb_extflat_hiersrarray_t (CallArg*) */
 
 int
 efVisitResists(hc, ca)
@@ -555,25 +561,28 @@ efVisitResists(hc, ca)
  * ----------------------------------------------------------------------------
  */
 
+/* @typedef cb_extflat_hiersrarray_t (CallArg*) */
 int
-efVisitSingleResist(hc, name1, name2, res, ca)
-    HierContext *hc;		/* Contains hierarchical pathname to cell */
-    char *name1, *name2;	/* Names of nodes connecting to resistor */
-    Connection *res;		/* Contains resistance to add */
-    CallArg *ca;
+efVisitSingleResist(
+    HierContext *hc,		/* Contains hierarchical pathname to cell */
+    const char *name1,
+    const char *name2,		/* Names of nodes connecting to resistor */
+    Connection *res,		/* Contains resistance to add */
+    ClientData cdata)
 {
-    EFNode *n1, *n2;
+    CallArg *ca = (CallArg *)CD2PTR(cdata);
+    const EFNode *n1, *n2;
     HashEntry *he;
 
     if ((he = EFHNLook(hc->hc_hierName, name1, "resist(1)")) == NULL)
 	return 0;
-    n1 = ((EFNodeName *) HashGetValue(he))->efnn_node;
+    n1 = ((const EFNodeName *) HashGetValue(he))->efnn_node;
     if (n1->efnode_flags & EF_KILLED)
 	return 0;
 
     if ((he = EFHNLook(hc->hc_hierName, name2, "resist(2)")) == NULL)
 	return 0;
-    n2 = ((EFNodeName *) HashGetValue(he))->efnn_node;
+    n2 = ((const EFNodeName *) HashGetValue(he))->efnn_node;
     if (n2->efnode_flags & EF_KILLED)
 	return 0;
 
@@ -581,9 +590,10 @@ efVisitSingleResist(hc, name1, name2, res, ca)
     if (n1 == n2)
 	return 0;
 
-    return (*ca->ca_proc)(n1->efnode_name->efnn_hier,
+    const cb_extflat_visitresists_t ca_visitresists_proc = (cb_extflat_visitresists_t) ca->ca_proc; /* FIXME temporary */
+    return (*ca_visitresists_proc)(n1->efnode_name->efnn_hier,
 		n2->efnode_name->efnn_hier,
-		res->conn_res, ca->ca_cdata);
+		res->conn_res, ca->ca_cdata); /* @invoke cb_extflat_visitresists_t */
 }
 
 /*
