@@ -19,8 +19,8 @@
  *
  */
 
-#ifndef _EXTRACT_H
-#define _EXTRACT_H
+#ifndef _MAGIC__EXTRACT__EXTRACT_H
+#define _MAGIC__EXTRACT__EXTRACT_H
 
 #include "utils/magic.h"
 #include "database/database.h"  /* TileTypeBitMask */
@@ -55,6 +55,7 @@ extern int ExtDoWarn;		/* Bitmask of above */
 #define DEV_RSUBCKT    12		/* Resistor-like subcircuit.	*/
 #define DEV_MSUBCKT    13		/* MOSFET-like subcircuit.	*/
 #define DEV_CSUBCKT    14		/* Capacitor-like subcircuit.	*/
+#define DEV_VERILOGA   15		/* Verilog-A model ("N" component) */
 
 /* Device names for .ext file output (new in version 7.2)	*/
 /* (defined in extract/ExtBasic.c *and* extflat/EFread.c)	*/
@@ -147,4 +148,4 @@ extern void ExtLabelOneRegion();
 extern void ExtInit();
 extern bool ExtGetDevInfo();
 
-#endif /* _EXTRACT_H */
+#endif /* _MAGIC__EXTRACT__EXTRACT_H */
