@@ -1041,7 +1041,7 @@ keys_and_buttons:
 				freeMagic(vis);
 			    }
 			    /* Print Carriage Return & Put back Tcl/Tk prompt */
-			    TxParseString("", NULL, NULL);
+			    TxParseString("");
 			}
 			else
 			{
@@ -1076,7 +1076,7 @@ keys_and_buttons:
 				TxSetPoint(KeyPressedEvent->x,
 					grXToMagic(KeyPressedEvent->y),
 					grCurrent.mw->w_wid);
-				TxParseString(macroDef, NULL, NULL);
+				TxParseString(macroDef);
 			    }
 			    freeMagic(macroDef);
 			}
