@@ -20,13 +20,13 @@
  * rcsid "$Header: /usr/cvsroot/magic-8.0/tiles/tile.h,v 1.3 2010/06/24 12:37:57 tim Exp $"
  */
 
-#ifndef _TILES_H
-#define	_TILES_H
+#ifndef _MAGIC__TILES__TILE_H
+#define	_MAGIC__TILES__TILE_H
 
-#ifndef _MAGIC_H
+#ifndef _MAGIC__UTILS__MAGIC_H
 #include "utils/magic.h"
 #endif
-#ifndef _GEOMETRY_H
+#ifndef _MAGIC__UTILS__GEOMETRY_H
 #include "utils/geometry.h"
 #endif
 
@@ -76,8 +76,6 @@ typedef struct tile
      */
 
 #ifdef HAVE_SYS_MMAN_H
-#include <sys/mman.h>
-#include <unistd.h>
 
 /* This is an on-demand Free List management */
 typedef Tile *TileStore;
@@ -85,9 +83,6 @@ typedef Tile *TileStore;
 /* Page size is 4KB so we mmap a segment equal to 64 pages */
 #define TILE_STORE_BLOCK_SIZE (4 * 1024 * 64)
 
-extern Tile *TileStoreFreeList;
-extern Tile *TileStoreFreeList_end;
-
 #endif /* HAVE_SYS_MMAN_H */
 
 #define	BOTTOM(tp)		((tp)->ti_ll.p_y)
@@ -139,6 +134,9 @@ typedef struct
 				 */
 } Plane;
 
+#define PlaneGetHint(pl)        ((pl)->pl_hint)
+#define PlaneSetHint(pl, ti)    ((pl)->pl_hint = (ti))
+
 /*
  * The following coordinate, INFINITY, is used to represent a
  * tile location outside of the tile plane.
@@ -176,17 +174,16 @@ typedef struct
  * ever needed by modules other than the tile module.
  */
 
-extern Plane *TiNewPlane(Tile *);
-extern void TiFreePlane(Plane *);
-extern void TiToRect(Tile *, Rect *);
-extern Tile *TiSplitX(Tile *, int);
-extern Tile *TiSplitY(Tile *, int);
-extern Tile *TiSplitX_Left(Tile *, int);
-extern Tile *TiSplitY_Bottom(Tile *, int);
-extern void  TiJoinX(Tile *, Tile *, Plane *);
-extern void  TiJoinY(Tile *, Tile *, Plane *);
-extern int   TiSrArea();
-extern Tile *TiSrPoint(Tile *, Plane *, Point *);
+extern Plane *TiNewPlane(Tile *tile);
+extern void TiFreePlane(Plane *plane);
+extern void TiToRect(const Tile *tile, Rect *rect);
+extern Tile *TiSplitX(Tile *tile, int x);
+extern Tile *TiSplitY(Tile *tile, int y);
+extern Tile *TiSplitX_Left(Tile *tile, int x);
+extern Tile *TiSplitY_Bottom(Tile *tile, int y);
+extern void  TiJoinX(Tile *tile1, Tile *tile2, Plane *plane);
+extern void  TiJoinY(Tile *tile1, Tile *tile2, Plane *plane);
+extern Tile *TiSrPoint(Tile *hint, Plane *plane, const Point *point);
 
 #define	TiBottom(tp)		(BOTTOM(tp))
 #define	TiLeft(tp)		(LEFT(tp))
@@ -241,10 +238,83 @@ extern Tile *TiSrPoint(Tile *, Plane *, Point *);
 /* See diagnostic subroutine version in tile.c */
 #define	TiSetBody(tp, b)	((tp)->ti_body = INT2CD((b)))
 #define	TiGetClient(tp)		((tp)->ti_client)
-#define	TiSetClient(tp,b)	((tp)->ti_client = INT2CD((b)))
+#define	TiGetClientINT(tp)	(CD2INT((tp)->ti_client))
+#define	TiGetClientPTR(tp)	(CD2PTR((tp)->ti_client))
+#define	TiSetClient(tp,cd)	((tp)->ti_client = (cd))
+#define	TiSetClientINT(tp,cd)	((tp)->ti_client = INT2CD((cd)))
+#define	TiSetClientPTR(tp,cd)	((tp)->ti_client = PTR2CD((cd)))
 
-Tile *TiAlloc(void);
-void TiFree(Tile *);
+extern Tile *TiAlloc(void);
+
+#ifdef __GNUC_STDC_INLINE__
+
+/* Provide compiler visibility of STDC 'inline' semantics */
+
+#ifdef HAVE_SYS_MMAN_H
+extern Tile *TileStoreFreeList;
+
+inline void
+TiFree(Tile *tile)
+{
+    tile->ti_client = PTR2CD(TileStoreFreeList);
+    TileStoreFreeList = tile;
+}
+#else
+/*
+ * --------------------------------------------------------------------
+ *
+ * TiFree ---
+ *
+ *	Release memory allocation for tiles
+ *
+ * Results:
+ *	None.
+ *
+ * --------------------------------------------------------------------
+ */
+
+inline void
+TiFree(Tile *tile)
+{
+    freeMagic((char *)tile);
+}
+#endif
+
+inline void
+TiFreeIf(Tile *tile)
+{
+    if (tile != NULL)
+        TiFree(tile);
+}
+
+inline void
+TiFree1(Tile **delay1, Tile *tile)
+{
+    TiFreeIf(*delay1);
+    *delay1 = tile;
+}
+
+inline void
+TiJoinX1(Tile **delay1, Tile *tile1, Tile *tile2, Plane *plane)
+{
+    TiFreeIf(*delay1);
+    TiJoinX(tile1, tile2, plane);
+}
+
+inline void
+TiJoinY1(Tile **delay1, Tile *tile1, Tile *tile2, Plane *plane)
+{
+    TiFreeIf(*delay1);
+    TiJoinY(tile1, tile2, plane);
+}
+#else
+/* To support older compilers (that don't auto emit based on -O level) */
+extern void TiFree(Tile *tile);
+extern void TiFreeIf(Tile *tile);
+extern void TiFree1(Tile **delay1, Tile *tile);
+extern void TiJoinX1(Tile **delay1, Tile *tile1, Tile *tile2, Plane *plane);
+extern void TiJoinY1(Tile **delay1, Tile *tile1, Tile *tile2, Plane *plane);
+#endif
 
 #define EnclosePoint(tile,point)	((LEFT(tile)   <= (point)->p_x ) && \
 					 ((point)->p_x   <  RIGHT(tile)) && \
@@ -314,10 +384,10 @@ void TiFree(Tile *);
 	((rp)->r_xbot = LEFT(tp), (rp)->r_ybot = BOTTOM(tp), \
 	 (rp)->r_xtop = RIGHT(tp), (rp)->r_ytop = TOP(tp))
 
-extern Rect TiPlaneRect;	/* Rectangle large enough to force area
+extern const Rect TiPlaneRect;	/* Rectangle large enough to force area
 				 * search to visit every tile in the
 				 * plane.  This is the largest rectangle
 				 * that should ever be painted in a plane.
 				 */
 
-#endif /* _TILES_H */
+#endif /* _MAGIC__TILES__TILE_H */
